MonoStackTrace class
Utility for filtering and combining stack traces in MonoBloc error handling.
MonoBloc captures stack traces at event dispatch time and combines them with error stack traces to provide complete debugging information.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
filtered(
StackTrace origin, StackTrace trace, String exclude) → StackTrace - Creates a filtered stack trace combining origin and error traces.